********************************************************************************
*********************MONTAJE BD ECEPOV-21 GENERAL*******************************
********************************************************************************

*******************************************************
********A) Unión de los ficheros de datos**************
*******************************************************


*NOTA INTRODUCTORIA: Los microdatos de la ECEPOV están divididos en tres ficheros:*/
/* 1) fichero del hogar, que contiene información de todos los miembros del hogar (menores y mayores de 16)*/
/* 2) fichero de adultos, que contiene información más detallada (ver registro de variables) para la población adulta (mayor de 16)*/
/* 3) fichero de vivienda, que contiene información sobre la vivienda y sus características.*/
/* Unir los tres ficheros es clave para poder contar con la información más completa posible, para unirlos hay dos varibles identificadoras*/
/* -IDEN o código identificador del cuestionario, que puede tomarse como un código que identifica el hogar y a su vivienda*/
/* -NPV o identificador de la persona dentro del hogar*/
/* con estas dos variables vamos a unir las tres bases de datos en una sola.*/
/* EL MONTAJE REQUIERE ACTUALIZAR LOS ENLACES


*1) Abrimos el fichero de hogar, que es el que utilizaremos de base para hacer la unión de las tres bases de datos*/
/* (ya que contiene información de todos los miembros del hogar o dicho de otro modo, es la que más casos tiene).*/
use "C:\Users\Usuario\Desktop\ecepov\ECEPOVhogar_2021.dta"

*2) Creamos un identificador (id) único para cada individuo
gen id_indiv= IDEN+ NPV

*3) Guardamos para ir a la BD de adultos y hacer la misma operación (imprescindible para poder unir ambas bases de datos)
save "C:\Users\Usuario\Desktop\ecepov\ECEPOVhogar_2021_r.dta"
clear 

*4) Abrimos el fichero de adultos
use "C:\Users\Usuario\Desktop\ecepov\ECEPOVadultos_2021.dta"

*5) Creamos un identificador (id) único para cada individuo
gen id_indiv= IDEN+ NPV

*6) Guardamos para volver a la BD de hogares
save "C:\Users\Usuario\Desktop\ecepov\ECEPOVadultos_2021_r.dta"
clear 

*7) Abrimos la BD de hogares creada
use "C:\Users\Usuario\Desktop\ecepov\ECEPOVhogar_2021_r.dta"

*8) Fusionamos la BD de hogares con la de adultos (1 to 1) 
merge 1:1 id_indiv using "C:\Users\Usuario\Desktop\ecepov\ECEPOVadultos_2021_r.dta"
**NOTA: 62.559 salen como "not matched", son los menores 16 por lo que todo OK.

*9) Fusionamos la nueva BD con la BD de vivienda (many to 1), esta vez utilizamos IDEN en lugar de id_indiv 
rename _merge _merge_hog_adult
merge m:1 IDEN using "C:\Users\Usuario\Desktop\ecepov\ECEPOVvivienda_2021.dta"
rename _merge _merge_viv
**NOTA: 100% casos unidos

*10) Usamos la función compress para reducir el peso del archivo
compress

*11) Guardamos y ya tenemos las tres bases de datos unidas en una sola
save "C:\Users\Usuario\Desktop\ecepov\ECEPOV.dta"



*******************************************************
********B) Etiquetaje y preparación de los datos*******
*******************************************************

*1) Pasamos todas las variables a numéricas
destring * , replace

*2) Añadimos etiquetas a variables y valores del HOGAR

*2.1) Etiquetas de variables
label variable	IDEN	"Identificador cuestionario (id vivienda y hogar)"
label variable	IDQ_PV	"Código de la provincia de residencia"
label variable	IDQ_MUN	"Código del municipio (>50.000)"
label variable	TAM_MUNI	"Tamaño municipio (según padrón 21)"
label variable	FACTOR	"Factor de elevación "
label variable	NPV	"Número de orden de la persona en el hogar"
label variable	SEXO	"Sexo"
label variable	MESN	"Mes de nacimiento"
label variable	ANON	"Año de nacimiento"
label variable	EDAD	"Edad"
label variable	NACIM	"Lugar de nacimiento"
label variable	PROVN	"Provincia española de nacimiento"
label variable	MUNIN	"Municipio español de nacimiento"
label variable	PNACIM	"País de nacimiento"
label variable	PNAC1	"País de nacionalidad 1"
label variable	PNAC2	"País de nacionalidad 2"
label variable	NAC	"Nacionalidad: Española / Extranjera"
label variable	ANOADQESP	"Año de adquisición de la nacionalidad española"
label variable	RE_01	"Rel. de parentesco de la persona 1 con el entrevistado"
label variable	RE_02	"Rel. de parentesco de la persona 2 con el entrevistado"
label variable	RE_03	"Rel. de parentesco de la persona 3 con el entrevistado"
label variable	RE_04	"Rel. de parentesco de la persona 4 con el entrevistado"
label variable	RE_05	"Rel. de parentesco de la persona 5 con el entrevistado"
label variable	RE_06	"Rel. de parentesco de la persona 6 con el entrevistado"
label variable	RE_07	"Rel. de parentesco de la persona 7 con el entrevistado"
label variable	RE_08	"Rel. de parentesco de la persona 8 con el entrevistado"
label variable	RE_09	"Rel. de parentesco de la persona 9 con el entrevistado"
label variable	RE_10	"Rel. de parentesco de la persona 10 con el entrevistado"
label variable	RE_11	"Rel. de parentesco de la persona 11 con el entrevistado"
label variable	RE_12	"Rel. de parentesco de la persona 12 con el entrevistado"
label variable	RE_13	"Rel. de parentesco de la persona 13 con el entrevistado"
label variable	RE_14	"Rel. de parentesco de la persona 14 con el entrevistado"
label variable	RE_15	"Rel. de parentesco de la persona 15 con el entrevistado"
label variable	RE_16	"Rel. de parentesco de la persona 16 con el entrevistado"
label variable	RE_17	"Rel. de parentesco de la persona 17 con el entrevistado"
label variable	RE_18	"Rel. de parentesco de la persona 18 con el entrevistado"
label variable	RE_19	"Rel. de parentesco de la persona 19 con el entrevistado"
label variable	ANOCONVICASAD	"Año desde el que convive con su cónyuge"
label variable	PARINSC	"Pareja inscrita en un registro"
label variable	ANOCONVIPAR	"Año desde el que convive con su pareja (no cónyuge)"
label variable	NPROGEN	"Número de progenitores que tiene o ha tenido"
label variable	REPROGEN1	"Relación de parentesco con su progenitor 1"
label variable	HOGP1	"El progenitor 1 reside en la vivienda"
label variable	NPVP1	"Nº de orden del progenitor1 en la lista de personas del hogar"
label variable	VIVOPROGEN1	"El progenitor 1 sigue vivo"
label variable	RESIDP1	"Lugar de residencia del progenitor 1"
label variable	PROVRP1	"Provincia española de residencia del progenitor 1"
label variable	MUNIRP1	"Municipio español de residencia del progenitor 1"
label variable	PRESIDP1	"País de residencia del progenitor 1"
label variable	NACIMP1	"Lugar de nacimiento del progenitor 1"
label variable	PROVNP1	"Provincia española de nacimiento del progenitor 1"
label variable	MUNINP1	"Municipio español de nacimiento del progenitor 1"
label variable	PNACIMP1	"País de nacimiento del progenitor 1"
label variable	PNAC1P1	"País de nacionalidad 1 del progenitor 1"
label variable	PNAC2P1	"País de nacionalidad 2 del progenitor 1"
label variable	ESTUDIOSP1	"Mayor nivel de estudios alcanzado por el progenitor 1"
label variable	REPROGEN2	"Relación de parentesco con su progenitor 2"
label variable	HOGP2	"El progenitor 2 reside en la vivienda"
label variable	NPVP2	"Nº de orden del progenitor2 en la lista de personas del hogar"
label variable	VIVOPROGEN2	"El progenitor 2 sigue vivo"
label variable	RESIDP2	"Lugar de residencia del progenitor 2"
label variable	PROVRP2	"Provincia española de residencia del progenitor 2"
label variable	MUNIRP2	"Municipio español de residencia del progenitor 2"
label variable	PRESIDP2	"País de residencia del progenitor 2"
label variable	NACIMP2	"Lugar de nacimiento del progenitor 2"
label variable	PROVNP2	"Provincia española de nacimiento del progenitor 2"
label variable	MUNINP2	"Municipio español de nacimiento del progenitor 2"
label variable	PNACIMP2	"País de nacimiento del progenitor 2"
label variable	PNAC1P2	"País de nacionalidad 1 del progenitor 2"
label variable	PNAC2P2	"País de nacionalidad 2 del progenitor 2"
label variable	ESTUDIOSP2	"Mayor nivel de estudios alcanzado por el progenitor 2"
label variable	RESIDVNACI	"Reside en esta vivienda desde el año en que nació"
label variable	ANORESIDVIV	"Año desde el que reside en esta vivienda"
label variable	MOTIVOCAMBIO	"Motivo del último cambio de residencia"
label variable	RESIDMUNNACI	"Reside en este municipio desde el año en que nació"
label variable	ANORESIDMUN	"Año desde el que reside en este municipio"
label variable	RESIDCANACI	"Reside en esta comunidad autónoma desde el año en que nació"
label variable	ANORESIDCA	"Año desde el que reside en esta comunidad autónoma"
label variable	RESIDESPNACI	"Reside en España desde el año en que nació"
label variable	ANORESIDESP	"Año desde el que reside en España"
label variable	RESIDANT	"Lugar de residencia anterior"
label variable	PROVRESIDANT	"Provincia de residencia anterior"
label variable	MUNIRESIDANT	"Municipio de residencia anterior"
label variable	PRESIDANT	"País de residencia anterior"
label variable	NOMLENG1	"Nombre de la 1ª lengua o idioma que conoce que será CASTELLANO"
label variable	ENTIENDEL1	"Nivel de conocimiento de la 1ª lengua: Entiende"
label variable	LEEL1	"Nivel de conocimiento de la 1ª lengua: Lee"
label variable	HABLAL1	"Nivel de conocimiento de la 1ª lengua: Habla"
label variable	ESCRIBEL1	"Nivel de conocimiento de la 1ª lengua: Escribe"
label variable	LENGFAM1	"Frecuencia con que usa la 1ª lengua en familia"
label variable	LENGAMIG1	"Frecuencia con que usa la 1ª lengua con amigos"
label variable	LENGTRAB1	"Frecuencia con que usa la 1ª lengua en el trabajo o escuela"
label variable	NOMLENG2	"Nombre de la 2ª lengua o idioma que conoce "
label variable	ENTIENDEL2	"Nivel de conocimiento de la 2ª lengua: Entiende"
label variable	LEEL2	"Nivel de conocimiento de la 2ª lengua: Lee"
label variable	HABLAL2	"Nivel de conocimiento de la 2ª lengua: Habla"
label variable	ESCRIBEL2	"Nivel de conocimiento de la 2ª lengua: Escribe"
label variable	LENGFAM2	"Frecuencia con que usa la 2ª lengua en familia"
label variable	LENGAMIG2	"Frecuencia con que usa la 2ª lengua con amigos"
label variable	LENGTRAB2	"Frecuencia con que usa la 2ª lengua en el trabajo o escuela"
label variable	NOMLENG3	"Nombre de la 3ª lengua o idioma que conoce"
label variable	ENTIENDEL3	"Nivel de conocimiento de la 3ª lengua: Entiende"
label variable	LEEL3	"Nivel de conocimiento de la 3ª lengua: Lee"
label variable	HABLAL3	"Nivel de conocimiento de la 3ª lengua: Habla"
label variable	ESCRIBEL3	"Nivel de conocimiento de la 3ª lengua: Escribe"
label variable	LENGFAM3	"Frecuencia con que usa la 3ª lengua en familia"
label variable	LENGAMIG3	"Frecuencia con que usa la 3ª lengua con amigos"
label variable	LENGTRAB3	"Frecuencia con que usa la 3ª lengua en el trabajo o escuela"
label variable	NOMLENG4	"Nombre de la 4ª lengua o idioma que conoce"
label variable	ENTIENDEL4	"Nivel de conocimiento de la 4ª lengua: Entiende"
label variable	LEEL4	"Nivel de conocimiento de la 4ª lengua: Lee"
label variable	HABLAL4	"Nivel de conocimiento de la 4ª lengua: Habla"
label variable	ESCRIBEL4	"Nivel de conocimiento de la 4ª lengua: Escribe"
label variable	LENGFAM4	"Frecuencia con que usa la 4ª lengua en familia"
label variable	LENGAMIG4	"Frecuencia con que usa la 4ª lengua con amigos"
label variable	LENGTRAB4	"Frecuencia con que usa la 4ª lengua en el trabajo o escuela"
label variable	NOMLENG5	"Nombre de la 5ª lengua o idioma que conoce"
label variable	ENTIENDEL5	"Nivel de conocimiento de la 5ª lengua: Entiende"
label variable	LEEL5	"Nivel de conocimiento de la 5ª lengua: Lee"
label variable	HABLAL5	"Nivel de conocimiento de la 5ª lengua: Habla"
label variable	ESCRIBEL5	"Nivel de conocimiento de la 5ª lengua: Escribe"
label variable	LENGFAM5	"Frecuencia con que usa la 5ª lengua en familia"
label variable	LENGAMIG5	"Frecuencia con que usa la 5ª lengua con amigos"
label variable	LENGTRAB5	"Frecuencia con que usa la 5ª lengua en el trabajo o escuela"
label variable	NOMLENG6	"Nombre de la 6ª lengua o idioma que conoce"
label variable	ENTIENDEL6	"Nivel de conocimiento de la 6ª lengua: Entiende"
label variable	LEEL6	"Nivel de conocimiento de la 6ª lengua: Lee"
label variable	HABLAL6	"Nivel de conocimiento de la 6ª lengua: Habla"
label variable	ESCRIBEL6	"Nivel de conocimiento de la 6ª lengua: Escribe"
label variable	LENGFAM6	"Frecuencia con que usa la 6ª lengua en familia"
label variable	LENGAMIG6	"Frecuencia con que usa la 6ª lengua con amigos"
label variable	LENGTRAB6	"Frecuencia con que usa la 6ª lengua en el trabajo o escuela"
label variable	LENGINICAST	"Lengua inicial: Castellano"
label variable	LENGINIGALL	"Lengua inicial: Gallego"
label variable	LENGINIEUSK	"Lengua inicial: Euskera"
label variable	LENGINICAT	"Lengua inicial: Catalán"
label variable	LENGINIVAL	"Lengua inicial: Valenciano"
label variable	LENGINIING	"Lengua inicial: Inglés"
label variable	LENGINIFRAN	"Lengua inicial: Francés"
label variable	LENGINIITA	"Lengua inicial: Italiano"
label variable	LENGINIALEM	"Lengua inicial: Alemán"
label variable	LENGINIRUM	"Lengua inicial: Rumano"
label variable	LENGINIARAB	"Lengua inicial: Árabe"
label variable	LENGINIOTRA	"Literal de otra lengua inicial que no está en la lista"
label variable	ESCUEINFANT	"Acude a alguna escuela infantil, guardería o centro escolar de otro tipo"
label variable	TIPOESCUINFANT	"Tipo de escuela infantil"
label variable	NUCLEO	"Orden de núcleo dentro del hogar de la persona entrevistada"
label variable	TIPONUCLEO	"Tipo de núcleo familiar"
label variable	SEXO_PAREJA	"Sexo de los miembros de la pareja"
label variable	NACION_PAREJA	"Nacionalidad de los miembros de la pareja"
label variable	UNION_PAREJA	"Tipo de unión de la pareja"
label variable	ESTUDIOS_PAREJA	"Nivel de estudios alcanzado por los miembros de la pareja"
label variable	SITLAB_PAREJA	"Situación laboral de los miembros de la pareja"
label variable	SITUHOGAR	"Situación familiar de la persona en el hogar"
label variable	HIJOS_NUCLEO_MENORES	"Cantidad de hijos menores de 25 años pertenecientes al núcleo familiar"
label variable	HIJOS_NUCLEO	"Cantidad de hijos pertenecientes al núcleo familiar"
label variable	TIPOHOGAR	"Tipo de hogar"
label variable	NACHOGAR	"Nacionalidad de los miembros del hogar"
label variable	NIVEDUCAHOGAR	"Nivel educativo de los miembros del hogar"
label variable	SITLABHOGAR	"Situación laboral de los miembros del hogar"

*2.2) Etiquetas de valores de variables (sigo el orden de aparición en la base de datos; las variables que no requieren etiquetas se han omitido; algunas que comparten etiqueta se han etiquetado juntas; hay notas insertadas sobre algunas apreciaciones inciales sobre los datos)
tab IDQ_MUN
label define IDQ_MUN /*
*/0	"Municipio <=50.000 habitantes o no capital"
label values IDQ_MUN IDQ_MUN1
tab IDQ_MUN

tab TAM_MUNI
label define TAM_MUNI /*
*/ 1"De 50.000 habitantes o menos"/*
*/ 2"De 50.001 a 100.000 habitantes"/*
*/ 3"De 100.001 a 500.000 habitantes"/*
*/ 4"Más de 500.000 habitantes"
label values TAM_MUNI TAM_MUNI
tab TAM_MUNI

tab SEXO
label define SEXO /*
*/ 1"Hombre"/*
*/ 2"Mujer"
label values SEXO SEXO
tab SEXO

tab NACIM
label define NACIM /*
*/1"España"/*
*/2"Extranjero"
label values NACIM NACIM
tab NACIM

tab PROVN
label define PROVN1 /*
*/	1	"Araba/Álava"	/*
*/	2	"Albacete"	/*
*/	3	"Alicante/Alacant"	/*
*/	4	"Almería"	/*
*/	5	"Ávila"	/*
*/	6	"Badajoz"	/*
*/	7	"Balears, Illes"	/*
*/	8	"Barcelona"	/*
*/	9	"Burgos"	/*
*/	10	"Cáceres"	/*
*/	11	"Cádiz"	/*
*/	12	"Castellón/Castelló"	/*
*/	13	"Ciudad Real"	/*
*/	14	"Córdoba"	/*
*/	15	"Coruña, A"	/*
*/	16	"Cuenca"	/*
*/	17	"Girona"	/*
*/	18	"Granada"	/*
*/	19	"Guadalajara"	/*
*/	20	"Gipuzkoa"	/*
*/	21	"Huelva"	/*
*/	22	"Huesca"	/*
*/	23	"Jaén"	/*
*/	24	"León"	/*
*/	25	"Lleida"	/*
*/	26	"Rioja, La"	/*
*/	27	"Lugo"	/*
*/	28	"Madrid"	/*
*/	29	"Málaga"	/*
*/	30	"Murcia"	/*
*/	31	"Navarra"	/*
*/	32	"Ourense"	/*
*/	33	"Asturias"	/*
*/	34	"Palencia"	/*
*/	35	"Palmas, Las"	/*
*/	36	"Pontevedra"	/*
*/	37	"Salamanca"	/*
*/	38	"Santa Cruz de Tenerife"	/*
*/	39	"Cantabria"	/*
*/	40	"Segovia"	/*
*/	41	"Sevilla"	/*
*/	42	"Soria"	/*
*/	43	"Tarragona"	/*
*/	44	"Teruel"	/*
*/	45	"Toledo"	/*
*/	46	"Valencia/València"	/*
*/	47	"Valladolid"	/*
*/	48	"Bizkaia"	/*
*/	49	"Zamora"	/*
*/	50	"Zaragoza"	/*
*/	51	"Ceuta"	/*
*/	52	"Melilla"	
label values PROVN PROVN1
tab PROVN

***NOTA: MUNIN -Municipio de nacimiento (para españoles)- Es exhaustivo, están todos los muncipios

tab PNACIM
label define PNACIM /*
*/	101	"Albania"	/*
*/	102	"Austria"	/*
*/	103	"Bélgica"	/*
*/	104	"Bulgaria"	/*
*/	106	"Chipre"	/*
*/	107	"Dinamarca"	/*
*/	108	"España"	/*
*/	109	"Finlandia"	/*
*/	110	"Francia"	/*
*/	111	"Grecia"	/*
*/	112	"Hungría"	/*
*/	113	"Irlanda"	/*
*/	115	"Italia"	/*
*/	117	"Luxemburgo"	/*
*/	118	"Malta"	/*
*/	121	"Países Bajos"	/*
*/	122	"Polonia"	/*
*/	123	"Portugal"	/*
*/	126	"Alemania"	/*
*/	128	"Rumanía"	/*
*/	131	"Suecia"	/*
*/	136	"Letonia"	/*
*/	141	"Estonia"	/*
*/	142	"Lituania"	/*
*/	143	"República Checa"	/*
*/	144	"República Eslovaca"	/*
*/	146	"Croacia"	/*
*/	147	"Eslovenia"	/*
*/	114	"Islandia"	/*
*/	116	"Liechtenstein"	/*
*/	119	"Mónaco"	/*
*/	120	"Noruega"	/*
*/	124	"Andorra"	/*
*/	125	"Reino Unido"	/*
*/	129	"San Marino"	/*
*/	130	"Santa Sede"	/*
*/	132	"Suiza"	/*
*/	135	"Ucrania"	/*
*/	137	"Moldavia"	/*
*/	138	"Belarús"	/*
*/	139	"Georgia"	/*
*/	145	"Bosnia y Herzegovina"	/*
*/	148	"Armenia"	/*
*/	154	"Rusia"	/*
*/	156	"Macedonia"	/*
*/	157	"Serbia"	/*
*/	158	"Montenegro"	/*
*/	199	"Otros países de Europa"	/*
*/	201	"Burkina Faso"	/*
*/	202	"Angola"	/*
*/	203	"Argelia"	/*
*/	204	"Benin"	/*
*/	205	"Botswana"	/*
*/	206	"Burundi"	/*
*/	207	"Cabo Verde"	/*
*/	208	"Camerún"	/*
*/	209	"Comores"	/*
*/	210	"Congo"	/*
*/	211	"Costa de Marfil"	/*
*/	212	"Djibouti"	/*
*/	213	"Egipto"	/*
*/	214	"Etiopía"	/*
*/	215	"Gabón"	/*
*/	216	"Gambia"	/*
*/	217	"Ghana"	/*
*/	218	"Guinea"	/*
*/	219	"Guinea-Bissau"	/*
*/	220	"Guinea Ecuatorial"	/*
*/	221	"Kenia"	/*
*/	222	"Lesotho"	/*
*/	223	"Liberia"	/*
*/	224	"Libia"	/*
*/	225	"Madagascar"	/*
*/	226	"Malawi"	/*
*/	227	"Mali"	/*
*/	228	"Marruecos"	/*
*/	229	"Mauricio"	/*
*/	230	"Mauritania"	/*
*/	231	"Mozambique"	/*
*/	232	"Namibia"	/*
*/	233	"Níger"	/*
*/	234	"Nigeria"	/*
*/	235	"República Centroafricana"	/*
*/	236	"Sudáfrica"	/*
*/	237	"Ruanda"	/*
*/	238	"Santo Tomé y Príncipe"	/*
*/	239	"Senegal"	/*
*/	240	"Seychelles"	/*
*/	241	"Sierra Leona"	/*
*/	242	"Somalia"	/*
*/	243	"Sudán"	/*
*/	244	"Swazilandia"	/*
*/	245	"Tanzania"	/*
*/	246	"Chad"	/*
*/	247	"Togo"	/*
*/	248	"Túnez"	/*
*/	249	"Uganda"	/*
*/	250	"República Democrática del Congo"	/*
*/	251	"Zambia"	/*
*/	252	"Zimbabwe"	/*
*/	253	"Eritrea"	/*
*/	254	"Sudán del Sur"	/*
*/	299	"Otros países de África"	/*
*/	301	"Canadá"	/*
*/	302	"Estados Unidos de América"	/*
*/	303	"México"	/*
*/	310	"Antigua y Barbuda"	/*
*/	311	"Bahamas"	/*
*/	312	"Barbados"	/*
*/	313	"Belice"	/*
*/	314	"Costa Rica"	/*
*/	315	"Cuba"	/*
*/	316	"Dominica"	/*
*/	317	"El Salvador"	/*
*/	318	"Granada"	/*
*/	319	"Guatemala"	/*
*/	320	"Haití"	/*
*/	321	"Honduras"	/*
*/	322	"Jamaica"	/*
*/	323	"Nicaragua"	/*
*/	324	"Panamá"	/*
*/	325	"San Vicente y las Granadinas"	/*
*/	326	"República Dominicana"	/*
*/	327	"Trinidad y Tobago"	/*
*/	328	"Santa Lucía"	/*
*/	329	"San Cristóbal y Nieves"	/*
*/	340	"Argentina"	/*
*/	341	"Bolivia"	/*
*/	342	"Brasil"	/*
*/	343	"Colombia"	/*
*/	344	"Chile"	/*
*/	345	"Ecuador"	/*
*/	346	"Guyana"	/*
*/	347	"Paraguay"	/*
*/	348	"Perú"	/*
*/	349	"Surinam"	/*
*/	350	"Uruguay"	/*
*/	351	"Venezuela"	/*
*/	399	"Otros países de América"	/*
*/	401	"Afganistán"	/*
*/	402	"Arabia Saudí"	/*
*/	403	"Bahréin"	/*
*/	404	"Bangladesh"	/*
*/	405	"Myanmar"	/*
*/	407	"China"	/*
*/	408	"Emiratos Árabes Unidos"	/*
*/	409	"Filipinas"	/*
*/	410	"India"	/*
*/	411	"Indonesia"	/*
*/	412	"Iraq"	/*
*/	413	"Irán"	/*
*/	414	"Israel"	/*
*/	415	"Japón"	/*
*/	416	"Jordania"	/*
*/	417	"Camboya"	/*
*/	418	"Kuwait"	/*
*/	419	"Laos"	/*
*/	420	"Líbano"	/*
*/	421	"Malasia"	/*
*/	422	"Maldivas"	/*
*/	423	"Mongolia"	/*
*/	424	"Nepal"	/*
*/	425	"Omán"	/*
*/	426	"Pakistán"	/*
*/	427	"Qatar"	/*
*/	430	"Corea"	/*
*/	431	"Corea del Norte"	/*
*/	432	"Singapur"	/*
*/	433	"Siria"	/*
*/	434	"Sri Lanka"	/*
*/	435	"Tailandia"	/*
*/	436	"Turquía"	/*
*/	437	"Vietnam"	/*
*/	439	"Brunei"	/*
*/	440	"Islas Marshall"	/*
*/	441	"Yemen"	/*
*/	442	"Azerbaiyán"	/*
*/	443	"Kazajstán"	/*
*/	444	"Kirguistán"	/*
*/	445	"Tayikistán"	/*
*/	446	"Turkmenistán"	/*
*/	447	"Uzbekistán"	/*
*/	448	"Bhután"	/*
*/	449	"Palestina. Estado Observador, no miembro de Naciones Unidas"	/*
*/	499	"Otros países de Asia"	/*
*/	501	"Australia"	/*
*/	502	"Fiji"	/*
*/	504	"Nueva Zelanda"	/*
*/	505	"Papúa Nueva Guinea"	/*
*/	506	"Islas Salomón"	/*
*/	507	"Samoa"	/*
*/	508	"Tonga"	/*
*/	509	"Vanuatu"	/*
*/	511	"Micronesia"	/*
*/	512	"Tuvalu"	/*
*/	513	"Islas Cook"	/*
*/	514	"Kiribati"	/*
*/	515	"Nauru"	/*
*/	516	"Palaos"	/*
*/	517	"Timor Oriental"	/*
*/	599	"Otros países de Oceanía"	
label values PNACIM PNACIM
tab PNACIM

tab PNAC1
tab PNAC2
label values PNAC1 PNACIM
label values PNAC2 PNACIM
tab PNAC1
tab PNAC2

tab NAC NACIM
label values NAC NACIM
tab NACIM

label define RE /*
*/	1	"Padre/Madre"	/*
*/	2	"Pareja del padre/madre"	/*
*/	3	"Cónyuge"	/*
*/	4	"Pareja"	/*
*/	5	"Hijo/a"	/*
*/	6	"Hijo/a de la pareja"	/*
*/	7	"Hermano/a"	/*
*/	8	"Abuelo/a"	/*
*/	9	"Nieto/a"	/*
*/	10	"Otro tipo de relación familiar"	/*
*/	11	"No tiene relación de parentesco"
label values RE_* RE

label define SINO1 1"Sí" 6"No" 0"NS/NC"
label values PARINSC SINO1
tab PARINS

tab NPROGEN
label define NPROGEN 0"NS/NC" 1"No ha tenido" 2"Uno" 3"Dos"
label values NPROGEN NPROGEN
tab NPROGEN 

tab REPROGEN1 REPROGEN2
label define REPROGEN 0"NS/NC" 1"Padre" 2"Madre"
label values REPROGEN* REPROGEN
tab REPROGEN1 REPROGEN2
***NOTA: el cruce de esta variables me sale raro. Me salen demasiado NS/NC y muchos hogares homoparentales ¿puede que los NC sean gente cuyo progenitor esté muerto? Habría que comprobar y si es así hay recodificar

tab HOGP1
label values HOGP* SINO1
tab HOGP1 HOGP2
***NOTA: de nuevo muchos NS/NC ¿CÓMO NO PUEDES SABER SI VIVEN TUS PADRES EN CASA? Cruzar con si viven o no

tab VIVOPROGEN1
label define VIVO 0"NS/NC" 1"Fallecido" 2"Vivo"
label values VIVOPROGEN* VIVO
tab VIVOPROGEN1
tab VIVOPROGEN2
***NOTA: Me sigue sorprendiendo la cantidad de NS/NC lo he cruzado con las variables anteriores y no encuentro ningún patrón para los NS/NC

tab RESIDP1
tab RESIDP2
label define RESIDP 0"NS/NC" 1"España" 2"Extranjero"
label values RESIDP* RESIDP
tab RESIDP1
tab RESIDP2
***NOTA: Sigue habiendo muchos NS/NC pero lo bueno es que casi siempre es el mismo número de personas por lo que posiblemetne sea gente que realmente no sabe nada de sus padres. Habría que cehquear

tab PROVRP1
tab PROVRP2
label define PROVN2 /*
*/	0	"NS/NC"	/*
*/	1	"Araba/Álava"	/*
*/	2	"Albacete"	/*
*/	3	"Alicante/Alacant"	/*
*/	4	"Almería"	/*
*/	5	"Ávila"	/*
*/	6	"Badajoz"	/*
*/	7	"Balears, Illes"	/*
*/	8	"Barcelona"	/*
*/	9	"Burgos"	/*
*/	10	"Cáceres"	/*
*/	11	"Cádiz"	/*
*/	12	"Castellón/Castelló"	/*
*/	13	"Ciudad Real"	/*
*/	14	"Córdoba"	/*
*/	15	"Coruña, A"	/*
*/	16	"Cuenca"	/*
*/	17	"Girona"	/*
*/	18	"Granada"	/*
*/	19	"Guadalajara"	/*
*/	20	"Gipuzkoa"	/*
*/	21	"Huelva"	/*
*/	22	"Huesca"	/*
*/	23	"Jaén"	/*
*/	24	"León"	/*
*/	25	"Lleida"	/*
*/	26	"Rioja, La"	/*
*/	27	"Lugo"	/*
*/	28	"Madrid"	/*
*/	29	"Málaga"	/*
*/	30	"Murcia"	/*
*/	31	"Navarra"	/*
*/	32	"Ourense"	/*
*/	33	"Asturias"	/*
*/	34	"Palencia"	/*
*/	35	"Palmas, Las"	/*
*/	36	"Pontevedra"	/*
*/	37	"Salamanca"	/*
*/	38	"Santa Cruz de Tenerife"	/*
*/	39	"Cantabria"	/*
*/	40	"Segovia"	/*
*/	41	"Sevilla"	/*
*/	42	"Soria"	/*
*/	43	"Tarragona"	/*
*/	44	"Teruel"	/*
*/	45	"Toledo"	/*
*/	46	"Valencia/València"	/*
*/	47	"Valladolid"	/*
*/	48	"Bizkaia"	/*
*/	49	"Zamora"	/*
*/	50	"Zaragoza"	/*
*/	51	"Ceuta"	/*
*/	52	"Melilla"	
label values PROVRP* PROVN2
tab PROVRP1
tab PROVRP2

***NOTA: MUNIRP1 y MUNIRP2 -municipio de residencia de los progenitores- son exahustivos (tienen todos los municipios de España, excepto para aquellos que contestan NS/NC)

tab PRESIDP1 
tab PRESIDP2
label define PNACIM2 /*
*/	0	"NS/NC"	/*
*/	101	"Albania"	/*
*/	102	"Austria"	/*
*/	103	"Bélgica"	/*
*/	104	"Bulgaria"	/*
*/	106	"Chipre"	/*
*/	107	"Dinamarca"	/*
*/	108	"España"	/*
*/	109	"Finlandia"	/*
*/	110	"Francia"	/*
*/	111	"Grecia"	/*
*/	112	"Hungría"	/*
*/	113	"Irlanda"	/*
*/	115	"Italia"	/*
*/	117	"Luxemburgo"	/*
*/	118	"Malta"	/*
*/	121	"Países Bajos"	/*
*/	122	"Polonia"	/*
*/	123	"Portugal"	/*
*/	126	"Alemania"	/*
*/	128	"Rumanía"	/*
*/	131	"Suecia"	/*
*/	136	"Letonia"	/*
*/	141	"Estonia"	/*
*/	142	"Lituania"	/*
*/	143	"República Checa"	/*
*/	144	"República Eslovaca"	/*
*/	146	"Croacia"	/*
*/	147	"Eslovenia"	/*
*/	114	"Islandia"	/*
*/	116	"Liechtenstein"	/*
*/	119	"Mónaco"	/*
*/	120	"Noruega"	/*
*/	124	"Andorra"	/*
*/	125	"Reino Unido"	/*
*/	129	"San Marino"	/*
*/	130	"Santa Sede"	/*
*/	132	"Suiza"	/*
*/	135	"Ucrania"	/*
*/	137	"Moldavia"	/*
*/	138	"Belarús"	/*
*/	139	"Georgia"	/*
*/	145	"Bosnia y Herzegovina"	/*
*/	148	"Armenia"	/*
*/	154	"Rusia"	/*
*/	156	"Macedonia"	/*
*/	157	"Serbia"	/*
*/	158	"Montenegro"	/*
*/	199	"Otros países de Europa"	/*
*/	201	"Burkina Faso"	/*
*/	202	"Angola"	/*
*/	203	"Argelia"	/*
*/	204	"Benin"	/*
*/	205	"Botswana"	/*
*/	206	"Burundi"	/*
*/	207	"Cabo Verde"	/*
*/	208	"Camerún"	/*
*/	209	"Comores"	/*
*/	210	"Congo"	/*
*/	211	"Costa de Marfil"	/*
*/	212	"Djibouti"	/*
*/	213	"Egipto"	/*
*/	214	"Etiopía"	/*
*/	215	"Gabón"	/*
*/	216	"Gambia"	/*
*/	217	"Ghana"	/*
*/	218	"Guinea"	/*
*/	219	"Guinea-Bissau"	/*
*/	220	"Guinea Ecuatorial"	/*
*/	221	"Kenia"	/*
*/	222	"Lesotho"	/*
*/	223	"Liberia"	/*
*/	224	"Libia"	/*
*/	225	"Madagascar"	/*
*/	226	"Malawi"	/*
*/	227	"Mali"	/*
*/	228	"Marruecos"	/*
*/	229	"Mauricio"	/*
*/	230	"Mauritania"	/*
*/	231	"Mozambique"	/*
*/	232	"Namibia"	/*
*/	233	"Níger"	/*
*/	234	"Nigeria"	/*
*/	235	"República Centroafricana"	/*
*/	236	"Sudáfrica"	/*
*/	237	"Ruanda"	/*
*/	238	"Santo Tomé y Príncipe"	/*
*/	239	"Senegal"	/*
*/	240	"Seychelles"	/*
*/	241	"Sierra Leona"	/*
*/	242	"Somalia"	/*
*/	243	"Sudán"	/*
*/	244	"Swazilandia"	/*
*/	245	"Tanzania"	/*
*/	246	"Chad"	/*
*/	247	"Togo"	/*
*/	248	"Túnez"	/*
*/	249	"Uganda"	/*
*/	250	"República Democrática del Congo"	/*
*/	251	"Zambia"	/*
*/	252	"Zimbabwe"	/*
*/	253	"Eritrea"	/*
*/	254	"Sudán del Sur"	/*
*/	299	"Otros países de África"	/*
*/	301	"Canadá"	/*
*/	302	"Estados Unidos de América"	/*
*/	303	"México"	/*
*/	310	"Antigua y Barbuda"	/*
*/	311	"Bahamas"	/*
*/	312	"Barbados"	/*
*/	313	"Belice"	/*
*/	314	"Costa Rica"	/*
*/	315	"Cuba"	/*
*/	316	"Dominica"	/*
*/	317	"El Salvador"	/*
*/	318	"Granada"	/*
*/	319	"Guatemala"	/*
*/	320	"Haití"	/*
*/	321	"Honduras"	/*
*/	322	"Jamaica"	/*
*/	323	"Nicaragua"	/*
*/	324	"Panamá"	/*
*/	325	"San Vicente y las Granadinas"	/*
*/	326	"República Dominicana"	/*
*/	327	"Trinidad y Tobago"	/*
*/	328	"Santa Lucía"	/*
*/	329	"San Cristóbal y Nieves"	/*
*/	340	"Argentina"	/*
*/	341	"Bolivia"	/*
*/	342	"Brasil"	/*
*/	343	"Colombia"	/*
*/	344	"Chile"	/*
*/	345	"Ecuador"	/*
*/	346	"Guyana"	/*
*/	347	"Paraguay"	/*
*/	348	"Perú"	/*
*/	349	"Surinam"	/*
*/	350	"Uruguay"	/*
*/	351	"Venezuela"	/*
*/	399	"Otros países de América"	/*
*/	401	"Afganistán"	/*
*/	402	"Arabia Saudí"	/*
*/	403	"Bahréin"	/*
*/	404	"Bangladesh"	/*
*/	405	"Myanmar"	/*
*/	407	"China"	/*
*/	408	"Emiratos Árabes Unidos"	/*
*/	409	"Filipinas"	/*
*/	410	"India"	/*
*/	411	"Indonesia"	/*
*/	412	"Iraq"	/*
*/	413	"Irán"	/*
*/	414	"Israel"	/*
*/	415	"Japón"	/*
*/	416	"Jordania"	/*
*/	417	"Camboya"	/*
*/	418	"Kuwait"	/*
*/	419	"Laos"	/*
*/	420	"Líbano"	/*
*/	421	"Malasia"	/*
*/	422	"Maldivas"	/*
*/	423	"Mongolia"	/*
*/	424	"Nepal"	/*
*/	425	"Omán"	/*
*/	426	"Pakistán"	/*
*/	427	"Qatar"	/*
*/	430	"Corea"	/*
*/	431	"Corea del Norte"	/*
*/	432	"Singapur"	/*
*/	433	"Siria"	/*
*/	434	"Sri Lanka"	/*
*/	435	"Tailandia"	/*
*/	436	"Turquía"	/*
*/	437	"Vietnam"	/*
*/	439	"Brunei"	/*
*/	440	"Islas Marshall"	/*
*/	441	"Yemen"	/*
*/	442	"Azerbaiyán"	/*
*/	443	"Kazajstán"	/*
*/	444	"Kirguistán"	/*
*/	445	"Tayikistán"	/*
*/	446	"Turkmenistán"	/*
*/	447	"Uzbekistán"	/*
*/	448	"Bhután"	/*
*/	449	"Palestina. Estado Observador, no miembro de Naciones Unidas"	/*
*/	499	"Otros países de Asia"	/*
*/	501	"Australia"	/*
*/	502	"Fiji"	/*
*/	504	"Nueva Zelanda"	/*
*/	505	"Papúa Nueva Guinea"	/*
*/	506	"Islas Salomón"	/*
*/	507	"Samoa"	/*
*/	508	"Tonga"	/*
*/	509	"Vanuatu"	/*
*/	511	"Micronesia"	/*
*/	512	"Tuvalu"	/*
*/	513	"Islas Cook"	/*
*/	514	"Kiribati"	/*
*/	515	"Nauru"	/*
*/	516	"Palaos"	/*
*/	517	"Timor Oriental"	/*
*/	599	"Otros países de Oceanía"	
label values PRESIDP* PNACIM2
tab PRESIDP1 
tab PRESIDP2

tab NACIMP1
tab NACIMP2
label values NACIMP* RESIDP
tab NACIMP1
tab NACIMP2

tab PROVNP1
tab PROVNP2
label values PROVNP* PROVN2
tab PROVNP1
tab PROVNP2

***NOTA: MUNIRP1 y MUNIRP2 -municipio de nacimiento de los progenitores- son exahustivos (tienen todos los municipios de España, excepto para aquellos que contestan NS/NC)

tab PNACIMP1
tab PNACIMP2
tab PNAC1P1
tab PNAC1P2
tab PNAC2P1
tab PNAC2P2
label values PNACIMP* PNACIM2
label values PNAC1P* PNACIM2
label values PNAC2P* PNACIM2
tab PNACIMP1
tab PNACIMP2
tab PNAC1P1
tab PNAC1P2
tab PNAC2P1
tab PNAC2P2

tab ESTUDIOSP1
tab ESTUDIOSP2
label define ESTUD1 /*
*/	0	"NS/NC"	/*
*/	1	"Analfabeto"	/*
*/	2	"Primaria incompleta"	/*
*/	3	"Primaria"	/*
*/	4	"Secundaria"	/*
*/	5	"Bachiller o equivalente"	/*
*/	6	"FP"	/*
*/	7	"FP2"	/*
*/	8	"FP3"	/*
*/	9	"Diplomado"	/*
*/	10	"Licenciado"	/*
*/	11	"Máster"	/*
*/	12	"Doctor"	
label values ESTUDIOSP* ESTUD1
tab ESTUDIOSP1
tab ESTUDIOSP2

tab RESIDVNACI
label values RESIDVNACI SINO1
tab RESIDVNACI

tab MOTIVOCAMBIO
label define MOTIVO /*
*/	1	"Necesidad de una casa más grande"	/*
*/	2	"Necesidad de una casa más pequeña"	/*
*/	3	"Calidad de la vivienda"	/*
*/	4	"Emancipación"	/*
*/	5	"Pasar a realizar una vida en pareja"	/*
*/	6	"Motivos económicos"	/*
*/	7	"Motivos laborales"	/*
*/	8	"Divorcio/Separación"	/*
*/	9	"Búsqueda de otra zona"	/*
*/	10	"Finalización del contrato de alquiler"	/*
*/	11	"Motivos de salud"	/*
*/	12	"Otro"	
label values MOTIVOCAMBIO MOTIVO
tab MOTIVOCAMBIO

tab RESIDMUNNACI
label values RESIDMUNNACI SINO1
tab RESIDMUNNACI

tab RESIDCANACI
label values RESIDCANACI SINO1
tab RESIDCANACI

tab RESIDESPNACI
label values RESIDESPNACI SINO1
tab RESIDESPNACI

tab RESIDANT
label values RESIDANT RESIDP
tab RESIDANT

tab PROVRESIDANT
label values PROVRESIDANT PROVN2
tab PROVRESIDANT

tab PRESIDANT
label values PRESIDANT PNACIM2
tab PRESIDANT

***NOTA:  Voy a eliminar la ristra brutal de variables sobre lenguas que hay porque creo que no aporta nada a nuestros intereses saber el nivel de manejos de distintas lenguas, dejos solo la lengua "incial" o nativa por si puede ser útil (por mi también las borraría)
drop NOMLENG1 ENTIENDEL1 LEEL1 HABLAL1 ESCRIBEL1 LENGFAM1 LENGAMIG1 LENGTRAB1 NOMLENG2 ENTIENDEL2 LEEL2 HABLAL2 ESCRIBEL2 LENGFAM2 LENGAMIG2 LENGTRAB2 NOMLENG3 ENTIENDEL3 LEEL3 HABLAL3 ESCRIBEL3 LENGFAM3 LENGAMIG3 LENGTRAB3 NOMLENG4 ENTIENDEL4 LEEL4 HABLAL4 ESCRIBEL4 LENGFAM4 LENGAMIG4 LENGTRAB4 NOMLENG5 ENTIENDEL5 LEEL5 HABLAL5 ESCRIBEL5 LENGFAM5 LENGAMIG5 LENGTRAB5 NOMLENG6 ENTIENDEL6 LEEL6 HABLAL6 ESCRIBEL6 LENGFAM6 LENGAMIG6 LENGTRAB6

tab ESCUEINFANT
label values ESCUEINFANT SINO1
tab ESCUEINFANT
***NOTA: Esta variable está solo para niños con 5 años o menos (como es lógico)

tab TIPOESCUINFANT
label define TIPOESCUINFANT 1"Público" 2"Privado" 3"Concertado"
label values TIPOESCUINFANT TIPOESCUINFANT
tab TIPOESCUINFANT

tab TIPONUCLEO
label define TIPONUCLEO /*
*/	1	"Matrimonio sin hijos"	/*
*/	2	"Matrimonio con hijos"	/*
*/	3	"Pareja no casada sin hijos"	/*
*/	4	"Pareja no casada con hijos"	/*
*/	5	"Padre sólo con hijos convivientes"	/*
*/	6	"Madre sóla con hijos convivientes"	
label values TIPONUCLEO TIPONUCLEO
tab TIPONUCLEO

tab SEXO_PAREJA
label define SEXO_PAREJA /*
*/	1	"Distinto sexo"	/*
*/	2	"Mismo sexo masculino"	/*
*/	3	"Mismo sexo femenino"	
label values SEXO_PAREJA SEXO_PAREJA
tab SEXO_PAREJA

tab NACION_PAREJA
label define NACION_PAREJA /*
*/	1	"Ambos españoles"	/*
*/	2	"Ambos extranjeros"	/*
*/	3	"Español con pareja extranjera"	/*
*/	4	"Española con pareja extranjera"	
label values NACION_PAREJA NACION_PAREJA
tab NACION_PAREJA

tab UNION_PAREJA
label define UNION_PAREJA /*
*/1	"Pareja casada"/*
*/2	"No casada, ambos solteros"/*
*/3	"No casada, otro tipo"
label values UNION_PAREJA UNION_PAREJA
tab UNION_PAREJA

tab ESTUDIOS_PAREJA
label define ESTUDIOS_PAREJA /*
*/	1	"Ninguno con estud. Universitarios"	/*
*/	2	"Uno con estud. Universitarios"	/*
*/	3	"Ambos con estud. Universitarios"	
label values ESTUDIOS_PAREJA ESTUDIOS_PAREJA
tab ESTUDIOS_PAREJA

tab SITLAB_PAREJA
label define SITLAB_PAREJA /*
*/	1	"Ambos trabajan"	/*
*/	2	"Uno trabaja y otro jubilado/incapacitado"	/*
*/	3	"Uno trabaja y otro no"	/*
*/	4	"Ambos jubilados/incapacitados"	/*
*/	5	"Uno jubilado/incapacitado y el otro no trabaja"	/*
*/	6	"Ambos sin trabajo"	
label values SITLAB_PAREJA SITLAB_PAREJA
tab SITLAB_PAREJA

tab SITUHOGAR
label define SITUHOGAR /*
*/	1	"Persona que vive sola"	/*
*/	2	"Padre/madre sólo/a con hijos en el hogar"	/*
*/	3	"Persona que vive en pareja, sin hijos en el hogar"	/*
*/	4	"Persona que vive en pareja, con hijos en el hogar"	/*
*/	5	"Hijo/a"	/*
*/	6	"Otro tipo de situaciones"	
label values SITUHOGAR SITUHOGAR
tab SITUHOGAR

tab TIPOHOGAR
label define TIPOHOGAR /*
*/	1	"Unipersonal"	/*
*/	2	"Monoparental"	/*
*/	3	"Pareja sin hijos"	/*
*/	4	"Pareja con hijos"	/*
*/	5	"Familia con otras personas"	/*
*/	6	"No familiar"	/*
*/	7	"Polinuclear"	
label values TIPOHOGAR TIPOHOGAR
tab TIPOHOGAR

tab NACHOGAR
label define NACHOGAR /*
*/	1	"Solo españoles"	/*
*/	2	"Mixto (expañoles y extranjeros)"	/*
*/	3	"Extranjeros (todos misma nacionalidad)"	/*
*/	4	"Extranjeros (distinta nacionalidad)"	
label values NACHOGAR NACHOGAR
tab NACHOGAR

tab NIVEDUCAHOGAR
label define NIVEDUCAHOGAR /*
*/1"Ninguno estud. superiores"/*
*/2"Alguno con estud. superiores"/*
*/3"Todos estud. superiores"
label values NIVEDUCAHOGAR NIVEDUCAHOGAR
tab NIVEDUCAHOGAR

tab SITLABHOGAR
label define SITLABHOGAR /*
*/	1	"Ninguno trabaja"	/*
*/	2	"Todos jubilados/incapacitados"	/*
*/	3	"Alguno jubilado/incapacitado y otro sin trabajo"	/*
*/	4	"Todos trabajan"	/*
*/	5	"Alguno trabajo y otro no"	/*
*/	6	"Alguno trabaja y otro es jubilado/incapacitado"	/*
*/	7	"Alguno trabajao, otro no y otro es jubilado/incapacitado"	
label values SITLABHOGAR SITLABHOGAR
tab SITLABHOGAR


*3) Añadimos etiquetas a variables y valores del fichero de ADULTOS

*3.1) Etiquetaje de variables
rename id_indiv ID_INDIV
label variable ID_INDIV "Identificador del individuo (creada IDEN+NPV)"
label variable	EC	"Estado civil legal"
label variable	ANOEC	"Año en el que adquirió su estado civil legal"
label variable	EDADEC	"Edad a la que adquirió su estado civil legal"
label variable	ESTUDIOS	"Nivel de estudios alcanzado"
label variable	ANOESTUD	"Año en el que alcanzó su mayor nivel de estudios"
label variable	EDADESTUD	"Edad a la que alcanzó su mayor nivel de estudios"
label variable	CAMPO	"Campo de los estudios "
label variable	SITLAB	"Situación laboral principal durante la última semana"
label variable	ANOSL	"Desde que año se encuentra en esa situación laboral"
label variable	EDADSL	"Desde que edad se encuentra en esa situación laboral"
label variable	FLEXI	"Puede flexibilizar jornada laboral por conciliación"
label variable	LUGTRAB	"Dónde está su lugar de trabajo/estudio"
label variable	NDESPLA	"Nº desplazamientos diarios trabajo"
label variable	MTRANSPOR_1	"Medio transporte 1 al trabajo"
label variable	MTRANSPOR_2	"Medio transporte 2 al trabajo"
label variable	TIEMDESPLA	"Tiempo de desplazamientos (todos) al trabajo"
label variable	SATISTIEMP	"Grado de satisfacción en el tiempo de desplazamiento al trabajo"
label variable	ACCESINTER	"Accede a internet al menos 5 días por semana"
label variable	REDSOCI	"Dispone de perfil en alguna red social"
label variable	SMART	"Dispone de teléfono móvil smartphone"
label variable	COMPRAINT	"En el último mes ha realizado la compra de artículos a través de internet"
label variable	VENDEINT	"En el último mes ha realizado la venta de artículos a través de internet"
label variable	HIJOS	"Ha tenido usted hijos"
label variable	NHIJOS	"Número total de hijos de la persona"
label variable	PAREJA	"Tiene pareja actualmente"
label variable	TDOMEST	"Grado de participación en las tareas domésticas de su hogar"
label variable	CUIDODHOG	"Grado de participación en los cuidados a personas dependientes del hogar"
label variable	NHSCDHOG	"Número de horas a la semana que dedica a cuidar a personas dependientes del hogar"
label variable	EDDEPDH	"Edad de la persona dependiente del hogar a la que más horas dedica"
label variable	TIPODEPDH	"Tipo de dependiente que es la persona del hogar a la que más horas dedica"
label variable	CUIDOFHOG	"Grado de participación en los cuidados a personas dependientes de fuera del hogar"
label variable	NHSCFHOG	"Número de horas a la semana que dedica a cuidar a personas dependientes de fuera del hogar"
label variable	EDDEPFH	"Edad de la persona dependiente de fuera del hogar a la que más horas dedica"
label variable	TIPODEPFH	"Tipo de dependiente que es la persona de fuera del hogar a la que más horas dedica"
label variable	GALI	"Limitaciones de actividad cotidiana por salud (ultimos 6 meses)"
label variable	APOSOCI	"Tiene a alguien con quien puede hablar de sus problemas cotidianos/sentimientos"
label variable	APOSOCIHIJ	"Personas que le dan apoyo social: Hijos/as"
label variable	APOSOCIPAMA	"Personas que le dan apoyo social: Padres/Madres"
label variable	APOSOCIHER	"Personas que le dan apoyo social: Hermanos/as"
label variable	APOSOCIOTPAR	"Personas que le dan apoyo social: Otro pariente"
label variable	APOSOCIOTRO	"Personas que le dan apoyo social: Otros: amigos, vecinos, etc."
label variable	LRESMD	"Lugar de residencia persona a menor distancia entre las personas que le dan apoyo social "

*3.2) Etiquetaje de valores
tab EC
label define EC /*
*/	1	"Soltero/a"	/*
*/	2	"Casado/a en primeras nupcias"	/*
*/	3	"Casado/a en segundas o más nupcias"	/*
*/	4	"Viudo/a"	/*
*/	5	"Separado/a"	/*
*/	6	"Divorciado/a"	
label values EC EC
tab EC

tab ESTUDIOS
label values ESTUDIOS ESTUD1
tab ESTUDIOS

tab CAMPO
label define CAMPO /*
*/ 1"Educación" /*
*/ 2"Artes y Humanidades" /*
*/ 3"Ciencias sociales" /*
*/ 4"Negocios y Derecho" /*
*/ 5"Ciencias" /*
*/ 6"Tecnologías de la información y comunicación" /*
*/ 7"Arquitectura, Ingeniería" /*
*/ 8"Agricultura, Ganadería, Pesca, Veterinaria" /*
*/ 9"Salud y Servicios Sociales" /*
*/ 10"Otros servicios (turismo, hostelería, peluquería)"
label values CAMPO CAMPO
tab CAMPO

tab SITLAB
label define SITLAB /*
*/	1	"Ocupado/a - A tiempo completo"		/*
*/	2	"Ocupado/a - A tiempo parcial"		/*
*/	3	"Estudiante"		/*
*/	4	"Parado/a - Ha trabajado anteriormente"		/*
*/	5	"Parado/a - No ha trabajado anteriormente"		/*
*/	6	"Jubilado/a, prejubilado/a"		/*
*/	7	"Incapacitado/a permanentemente para trabajar"		/*
*/	8	"Dedicado/a las tareas del hogar"		/*
*/	9	"Otro tipo de inactividad"		
label values SITLAB SITLAB
tab SITLAB

tab FLEXI 
label values FLEXI SINO1
tab FLEXI

tab LUGTRAB
label define LUGTRAB /*
*/	1	"En el propio domicilio"	/*
*/	2	"En varios municipios (soy comercial, repartidor, taxista…)"	/*
*/	3	"En el municipio en el que resido"	/*
*/	4	"En otro municipio de la misma provincia"	/*
*/	5	"En otro municipio de otra provincia"	/*
*/	6	"En otro país"	
label values LUGTRAB LUGTRAB
tab LUGTRAB

tab NDESPLA
label define NDESPLA 5"5 o más"
label values NDESPLA NDESPLA 
tab NDESPLA

tab MTRANSPOR_1
tab MTRANSPOR_2
label define MEDIO /*
*/	1	"Coche - particular"		/*
*/	2	"Coche - de empresa"		/*
*/	3	"Coche - de terceros - taxi"		/*
*/	4	"Coche - de terceros - VTC"		/*
*/	5	"Coche - de terceros - de una compañía sharing"		/*
*/	6	"Coche - de terceros - vehiculo compartido"		/*
*/	7	"En moto - particular"		/*
*/	8	"En moto - de una compañía sharing"		/*
*/	9	"En bicicleta - particular"		/*
*/	10	"En bicicleta - de una compañía de sharing"		/*
*/	11	"En autobús, autocar, minibús - transporte público"		/*
*/	12	"En autobús, autocar, minibús - servicio de empresa"		/*
*/	13	"Otros - en metro"		/*
*/	14	"Otros - en tranvía o metro ligero"		/*
*/	15	"Otros - andando"		/*
*/	16	"Otros - en tren"		/*
*/	17	"Otros - otros medios"		
label values MTRANSPOR_* MEDIO

tab TIEMDESPLA
label define TIEMPO /*
*/	1	"Menos de 20 minutos"		/*
*/	2	"Entre 20 y 39 minutos"		/*
*/	3	"Entre 40 y 59 minutos"		/*
*/	4	"Entre 60 y 89 minutos"		/*
*/	5	"Entre 90 y 119 minutos"		/*
*/	6	"Entre 2 horas y 2 horas y media"		/*
*/	7	"Más de 2 horas y media"		
label values TIEMDESPLA TIEMPO
tab TIEMDESPLA

tab SATISTIEMP
label variable SATISTIEMP "Satisfaccion en el tiempo de desplazamiento al trabajo (0-10)"

tab ACCESINTER
label values ACCESINTER SINO1
tab ACCESINTER

tab REDSOCI
label values REDSOCI SINO1
tab REDSOCI

tab SMART
label values SMART SINO1
tab SMART

tab COMPRAINT
label values COMPRAINT SINO1
tab COMPRAINT

tab VENDEINT
label values VENDEINT SINO1
tab VENDEINT

tab HIJOS
label values HIJOS SINO1
tab HIJOS

tab PAREJA
label values PAREJA SINO1
tab PAREJA

tab TDOMEST
label define TDOMEST /*
*/ 1"Me encargo mayor parte" /*
*/ 2"Me encargo parte importante" /*
*/ 3"Me encargo pequeña parte" /*
*/ 4"No participo"
label values TDOMEST TDOMEST
tab TDOMEST

tab CUIDODHOG
label define CUIDODHOG /*
*/ 1"Me encargo mayor parte" /*
*/ 2"Me encargo parte importante" /*
*/ 3"Me encargo pequeña parte" /*
*/ 4"No hay dependientes" /*
*/ 5"No participo"
label values CUIDODHOG CUIDODHOG
tab CUIDODHOG

tab TIPODEPDH
label define TIPODEPDH /*
*/1"Enfermo crónico" /*
*/2"Discapacitado" /*
*/3"Menor de edad" /*
*/4"Mayor de 70 u otro tipo"
label values TIPODEPDH TIPODEPDH
tab TIPODEPDH

tab CUIDOFHOG
label values CUIDOFHOG CUIDODHOG
tab CUIDOFHOG

tab TIPODEPFH
label values TIPODEPFH TIPODEPDH
tab TIPODEPFH

tab GALI
label define GALI 1"Gravemente limitado" 2"Limitado, no gravemente" 3"Nada limitado"
label values GALI GALI
tab GALI

tab APOSOCI
label values APOSOC* SINO1
tab APOSOCI

tab LRESMD
label define LRESMD /*
*/	1	"En el mismo municipio"		/*
*/	2	"En otro municipio de la misma provincia"		/*
*/	3	"En otra provincia de la misma comunidad autónoma"		/*
*/	4	"En otra comunidad autónoma dentro de España"		/*
*/	5	"En otro país"		
label values LRESMD LRESMD
tab LRESMD

**Borro el merge hogar_individuso (100% estaban unidos)
drop _merge_hog_adult

*4) Añadimos etiquetas a variables y valores del fichero de VIVIENDA

*4.1) Etiquetaje de variables
label variable	MESENT	"Mes comienzo de la entrevista"
label variable	ANOENT	"Año comienzo de la entrevista"
label variable	YORESI	"Informante reside en la vivienda"
label variable	OTRORESI	"Otras personas residen en la vivienda"
label variable	NRESI	"Número de residentes en la vivienda"
label variable	REGVI	"Régimen de tenencia de la vivienda"
label variable	PAGOVI	"Cuota mensual que paga de hipoteca o alquiler intervalizada"
label variable	CALEFAC	"Dispone la vivienda de calefacción"
label variable	TIPOCOMBCALE	"Tipo de combustible principal que usa su calefacción"
label variable	TIPOAGUA	"Sistema de suministro de agua en su vivienda"
label variable	WC	"Dispone la vivienda de cuarto de aseo con inodoro"
label variable	BODUCHA	"Dispone de bañera o ducha"
label variable	AIREACOND	"Dispone de aire acondicionado"
label variable	AISLAM	"La vivienda tiene algún problema de aislamiento"
label variable	ADAPTADA	"La vivienda está adaptada a necesidades propias del envejecimiento de las personas"
label variable	INTERNET	"Dispone la vivienda de acceso a internet"
label variable	INTFIJABANCHA	"Tipo de internet fija de banda ancha"
label variable	INTMOVBANCHA	"Tipo de internet móvil "
label variable	INTBESTRECHA	"Tipo de internet banda estrecha"
label variable	COCINA	"Dispone la vivienda de cocina independiente (de 4 m2 o más)"
label variable	LAVADORA	"Dispone la vivienda de lavadora"
label variable	LAVAVAJILLAS	"Dispone la vivienda de lavavajillas"
label variable	SECADORA	"Dispone la vivienda de secadora"
label variable	HORNO	"Dispone la vivienda de horno"
label variable	MICROONDAS	"Dispone la vivienda de microondas"
label variable	VITROINDUC	"Dispone la vivienda de vitrocerámica y/o inducción"
label variable	NASEOS	"Numero de cuartos de baño o aseos de la vivienda"
label variable	NSALONES	"Numero de salones, comedores o cuartos de estar de la vivienda"
label variable	NDORMITO	"Numero de dormitorios de la vivienda"
label variable	NSOTOTRAST	"Numero de buhardillas, sótanos o trasteros de la vivienda"
label variable	NOTRASHABIT	"Numero de otras estancias de la vivienda excluyendo cocinas, garajes, pasillos, vestíbulos, vestidores, despensas, terrazas abiertas y dependencias utilizadas para fines profesionales"
label variable	METROSVI	"Metros cuadrados de la vivienda"
label variable	VEHICULO	"Dispone el hogar de algún vehículo"
label variable	NVEHICULOS	"Número de vehículos de los que dispone el hogar"
label variable	VEHIELECTR	"Alguno de los vehículos del hogar es eléctrico"
label variable	VEHIHIBRI	"Alguno de los vehículos del hogar es híbrido"
label variable	PAPEL	"En su hogar separan los residuos de papel y cartón"
label variable	VIDRIO	"En su hogar separan los residuos de vidrio"
label variable	ENVASES	"En su hogar separan los residuos de envases"
label variable	ORGANICO	"En su hogar separan los residuos de materia orgánica"
label variable	HALOGENA	"Dispone su vivienda de bombillas halógenas"
label variable	BAJOCONSUMO	"Dispone su vivienda de bombillas de bajo consumo"
label variable	LED	"Dispone su vivienda de bombillas de LED"
label variable	SERVDOMES	"Dispone el hogar de servicio doméstico remunerado"
label variable	AYUDAEXT	"Dispone el hogar de ayudas externas para tareas domésticas y cuidado de menores o mayores dependientes"
label variable	RUIDOS	"Problema: Ruido"
label variable	CONTAMIN	"Problema: Contaminación/Olores"
label variable	SUCIO	"Problema: Limpieza"
label variable	MALCOMUNIC	"Problema: Malas comunicaciones"
label variable	POCOVERDE	"Problema: Falta zonas verdes"
label variable	DELINCUENCIA	"Problema: Delincuencia"
label variable	MOLESTURIST	"Problemas: Actividad turística/hostelera"
label variable	COLEGIO	"Servicios: Colegios"
label variable	CSALUD	"Servicios: Servicios sanitarios"
label variable	SUPER	"Servicios: Supermercados"
label variable	FARMACIA	"Servicios: Farmacias"
label variable	BARES	"Servicios: Restauración (bares…)"
label variable	CAMBIORESI	"Cambiará de residencia en los próximos 6 meses por problemas económicos"
label variable	SEGUNRESI	"Dispone de una segunda residencia en propiedad"
label variable	LUGSEGUNRESI	"Dónde se encuentra su segunda residencia"
label variable	OTRACCAA	"Comunidad autónoma en la que se encuentra su segunda residencia"
label variable	OTROPAIS	"País en el que se encuentra su segunda residencia"
label variable	DIASUSA	"Nº días al año que usa segunda residencia alguna persona del hogar"
label variable	INGREHOG	"Ingresos mensuales netos del hogar en intervalos"
label variable	TIPOEDIF	"Tipo de edificio en que se encuentra la vivienda"
label variable	TIPOEDIFVIV	"Tipo de edificio en función del número de viviendas"
label variable	NPLANTASSOB	"Número de plantas sobre rasante (sin contar la planta baja)"
label variable	NPLANTASBAJO	"Número de plantas bajo rasante (sin contar la planta baja)"
label variable	ANNOEDIFINTERV	"Año de construcción del edificio en intervalos"
label variable	ESTADOEDIF	"Estado de conservación del edificio (escala de 0 a 10)"
label variable	ACCESOEDIF	"El edificio es de fácil acceso a cualquier persona."
label variable	ASCENSOR	"El edificio tiene ascensor"
label variable	GARAJE	"El edificio tiene garaje"
label variable	NPLAZASGAR	"Número de plazas de aparcamiento del garaje"
label variable	GASTUBERIA	"El edificio tiene gas por tubería"
label variable	AGUACALCENT	"El edificio tiene agua caliente central"
label variable	EVACUAGUARES	"El edificio tiene sistema de evacuación de aguas residuales"
label variable	TIPOEVACUARES	"Tipo de sistema de evacuación de aguas residuales"
label variable	ENERENOV	"El edificio tiene instalación de dispositivo de energía renovable"
label variable	ERSOLAR	"Tipo de energía renovable: Energía solar térmica (para agua caliente)"
label variable	ERFOTOV	"Tipo de energía renovable: Energía solar fotovoltaica (para producir electricidad)"
label variable	EROTRO	"Tipo de energía renovable: Otro tipo (eólica, biomasa…)"
label variable	NVIVIENDP	"Número de viviendas que hay en la planta en al que reside"

*4.2) Etiquetaje de valores
tab YORESI
label values YORESI SINO1
tab YORESI

tab OTRORESI
label values OTRORESI SINO1
tab OTRORESI

tab REGVI
label define REGVI /*
*/1"Propiedad heredada" /*
*/2"Propiedad pagada" /*
*/3"Propiedad hipotecada" /*
*/4"Alquilada" /*
*/5"Cedida"/*
*/6"Otra forma"
label values REGVI REGVI
tab REGVI

tab PAGOVI
label define PAGOVI /*
*/	1	"<100€"	/*
*/	2	"De 100€ a 200€"	/*
*/	3	"De 200€ a 300€"	/*
*/	4	"De 300€ a 400€"	/*
*/	5	"De 400€ a 500€"	/*
*/	6	"De 500€ a 600€"	/*
*/	7	"De 600€ a 700€"	/*
*/	8	"De 700€ a 800€"	/*
*/	9	"De 800€ a 900€"	/*
*/	10	"De 900€ a 1.000€"	/*
*/	11	"De 1.000€ a 1.250€"	/*
*/	12	"De 1.250€ a 1.500€"	/*
*/	13	"De 1.500€ a 2.000€"	/*
*/	14	"De 2.000€ a 3.000€"	/*
*/	15	"De 3.000€ a 5.000€"	/*
*/	16	"De 5.000€ o más"	
label values PAGOVI PAGOVI
tab PAGOVI

tab CALEFAC
label define CALEFAC /*
*/1"No tiene"/*
*/2"Sí, colectiva"/*
*/3"Sí, individual"/*
*/4"Solo algún aparato para calentar"
label values CALEFAC CALEFAC
tab CALEFAC

tab TIPOCOMBCALE
label define TIPOCOMBCALE/*
*/	1	"Gas natural"	/*
*/	2	"Gas butano o propano"	/*
*/	3	"Electricidad"	/*
*/	4	"Petróleo o derivados (gasoil, fueloil, gasolina…)"	/*
*/	5	"Madera, pellets,…"	/*
*/	6	"Carbón o derivados"	/*
*/	7	"Energía renovable (solar, aerotermia, geotermia…)"	/*
*/	8	"Otros"	
label values TIPOCOMBCALE TIPOCOMBCALE
tab TIPOCOMBCALE

tab TIPOAGUA
label define TIPOAGUA1 /*
*/1"Abastecimiento público"/*
*/2"Abastecimiento privado"/*
*/3"No tiene agua"
label values TIPOAGUA TIPOAGUA1
tab TIPOAGUA

tab WC
label values WC SINO1
tab WC

tab BODUCHA
label values BODUCHA SINO1
tab BODUCHA

tab AIREACOND
label values AIREACOND SINO1
tab AIREACOND

tab AISLAM
label values AISLAM SINO1
tab AISLAM

tab ADAPTADA
label values ADAPTADA SINO1
tab ADAPTADA

tab INTERNET
label values INTERNET SINO1
tab INTERNET

label define SINO2 1"Sí" 2"No"

label values	INTFIJABANCHA	SINO2
label values	INTMOVBANCHA	SINO2
label values	INTBESTRECHA	SINO2
label values	COCINA	SINO2
label values	LAVADORA	SINO2
label values	LAVAVAJILLAS	SINO2
label values	SECADORA	SINO2
label values	HORNO	SINO2
label values	MICROONDAS	SINO2
label values	VITROINDUC	SINO2

tab METROSVI
label define METROSVI /*
*/	1	"Hasta 30 m2"	/*
*/	2	"Entre 31 y 45 m2"	/*
*/	3	"Entre 46 y 60 m2"	/*
*/	4	"Entre 61 y 75 m2"	/*
*/	5	"Entre 76 y 90 m2"	/*
*/	6	"Entre 91 y 105 m2"	/*
*/	7	"Entre 106 y 120 m2"	/*
*/	8	"Entre 121 y 150 m2"	/*
*/	9	"Entre 151 y 180 m2"	/*
*/	10	"Más de 180 m2"	
label values METROSVI METROSVI
tab METROSVI

tab VEHICULO
label values VEHICULO SINO1
tab VEHICULO

label values	VEHIELECTR	SINO1
label values	VEHIHIBRI	SINO1
label values	PAPEL	SINO1
label values	VIDRIO	SINO1
label values	ENVASES	SINO1
label values	ORGANICO	SINO1
label values	HALOGENA	SINO1
label values	BAJOCONSUMO	SINO1
label values	LED	SINO1

tab SERVDOMES
label define SERVDOMES /*
*/1"Sí, interno"/*
*/2"Sí, externo"/*
*/3"No"
label values SERVDOMES SERVDOMES
tab SERVDOMES

tab AYUDAEXT
label define AYUDAEXT /*
*/1"Sí, familiares, amigos..."/*
*/2"Sí, servicios sociales u ONG"/*
*/3"No"
label values AYUDAEXT AYUDAEXT
tab AYUDAEXT

label values	RUIDOS	SINO1
label values	CONTAMIN	SINO1
label values	SUCIO	SINO1
label values	MALCOMUNIC	SINO1
label values	POCOVERDE	SINO1
label values	DELINCUENCIA	SINO1
label values	MOLESTURIST	SINO1
label values	COLEGIO	SINO1
label values	CSALUD	SINO1
label values	SUPER	SINO1
label values	FARMACIA	SINO1
label values	BARES	SINO1
label values	CAMBIORESI	SINO1
label values	SEGUNRESI	SINO1

tab LUGSEGUNRESI
label define LUGSEGUNRESI /*
*/	1	"En el mismo municipio que la primera residencia"	/*
*/	2	"En otro municipio de la misma provincia"	/*
*/	3	"En otra provincia, pero en la misma CCAA"	/*
*/	4	"En otra CCAA"	/*
*/	5	"En el extranjero"	
label values LUGSEGUNRESI LUGSEGUNRESI
tab LUGSEGUNRESI

tab OTRACCAA
label define CCAA /*
*/	1	"Andalucía"	/*
*/	2	"Aragón"	/*
*/	3	"Asturias, Principado de"	/*
*/	4	"Balears, Illes"	/*
*/	5	"Canarias"	/*
*/	6	"Cantabria"	/*
*/	7	"Castilla y León"	/*
*/	8	"Castilla - La Mancha"	/*
*/	9	"Cataluña"	/*
*/	10	"Comunitat Valenciana"	/*
*/	11	"Extremadura"	/*
*/	12	"Galicia"	/*
*/	13	"Madrid, Comunidad de"	/*
*/	14	"Murcia, Región de"	/*
*/	15	"Navarra, Comunidad Foral de"	/*
*/	16	"País Vasco"	/*
*/	17	"Rioja, La"	/*
*/	18	"Ceuta"	/*
*/	19	"Melilla"	
label values OTRACCAA CCAA
tab OTRACCAA

tab OTROPAIS
label values OTROPAIS PNACIM2
tab OTROPAIS

tab DIASUSA
label define DIASUSA /*
*/	1	"Menos de 15 días"	/*
*/	2	"Entre 15 y 29 días"	/*
*/	3	"Entre 30 y 59 días"	/*
*/	4	"60 o más días"	
label values DIASUSA DIASUSA
tab DIASUSA

tab INGREHOG
label define INGREHOG /*
*/	1	"Menos de 500€"	/*
*/	2	"500€ a 1.000€"	/*
*/	3	"1.000€ a 1.500€"	/*
*/	4	"1.500€ a 2.000€"	/*
*/	5	"2.000€ a 2.500€"	/*
*/	6	"2.500€ a 3.000€"	/*
*/	7	"3.000€ a 5.000€"	/*
*/	8	"5.000€ a 7.500€"	/*
*/	9	"7.500€ o más"	
label values INGREHOG INGREHOG
tab INGREHOG

tab TIPOEDIF
label define TIPOEDIF 1"Unifamiliar" 2"Multifamiliar"
label values TIPOEDIF TIPOEDIF
tab TIPOEDIF

tab TIPOEDIFVIV
label define TIPOEDIFVIV 1"Unifamiliar" 2"Edificio 2 viviendas" 3"Edificio de 3 a 9 viviendas" 4"Edificios más 10 viviendas"
label value TIPOEDIFVIV TIPOEDIFVIV
tab TIPOEDIFVIV

tab ANNOEDIFINTERV
label define ANOEDIF /*
*/	1	"Anterior a  1900"	/*
*/	2	"De 1900 a 1920"	/*
*/	3	"De 1921 a 1940"	/*
*/	4	"De 1941 a 1950"	/*
*/	5	"De 1951 a 1960"	/*
*/	6	"De 1961 a 1970"	/*
*/	7	"De 1971 a 1980"	/*
*/	8	"De 1981 a 1990"	/*
*/	9	"De 1991 a 2000"	/*
*/	10	"De 2001 a 2010"	/*
*/	11	"Posterior a 2010"	
label values ANNOEDIFINTERV ANOEDIF
tab ANNOEDIFINTERV

label values ACCESOEDIF SINO2

label values ASCENSOR SINO1
label values GARAJE SINO1

tab NPLAZASGAR
label define NPLAZASGAR /*
*/	1	"1"	/*
*/	2	"2"	/*
*/	3	"De 3 a 5"	/*
*/	4	"De 6 a 10"	/*
*/	5	"De 11 a 20"	/*
*/	6	"De 21 a 50"	/*
*/	7	"De 51 a 100"	/*
*/	8	"De 101 a 150"	/*
*/	9	"Más de 150"	
label values NPLAZASGAR NPLAZASGAR
tab NPLAZASGAR

label values	GASTUBERIA	SINO2
label values	AGUACALCENT	SINO2
label values	EVACUAGUARES	SINO2
label values	ENERENOV	SINO2
label values	ERSOLAR	SINO1
label values	ERFOTOV	SINO1
label values	EROTRO	SINO1

tab TIPOEVACUARES
label define TIPOEVACUARES 1"Alcantarillado" 2"Otro tipo"
label values TIPOEVACUARES TIPOEVACUARES
tab TIPOEVACUARES

tab NVIVIENDP
label define NVIVIENDP /*
*/	1	"1"	/*
*/	2	"2"	/*
*/	3	"3"	/*
*/	4	"4"	/*
*/	5	"De 5 a 9"	/*
*/	6	"10 o más"	
label values NVIVIENDP NVIVIENDP
tab NVIVIENDP

***borro el drop que unía el fichero de vivienda con el de adultos-hogares (100% merge)
drop _merge

*GUARDAMOS
save "C:\Users\Usuario\Desktop\ecepov\ECEPOV_final.dta"